# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/annotations/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/annotations/resource.proto\x12\x11\x65nvoy.annotations\x1a google/protobuf/descriptor.proto\"\"\n\x12ResourceAnnotation\x12\x0c\n\x04type\x18\x01 \x01(\t:[\n\x08resource\x12\x1f.google.protobuf.ServiceOptions\x18\xc1\xe4\xb2~ \x01(\x0b\x32%.envoy.annotations.ResourceAnnotationB:Z8github.com/envoyproxy/go-control-plane/envoy/annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.annotations.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/envoyproxy/go-control-plane/envoy/annotations'
  _globals['_RESOURCEANNOTATION']._serialized_start=89
  _globals['_RESOURCEANNOTATION']._serialized_end=123
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3/sni_dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n]envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3/sni_dynamic_forward_proxy.proto\x12=envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa9\x01\n\x0c\x46ilterConfig\x12\x64\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12!\n\nport_value\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03 \x00H\x00\x42\x10\n\x0eport_specifierB\xf7\x01\nKio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3B\x1bSniDynamicForwardProxyProtoP\x01Z\x80\x01github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3;sni_dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3.sni_dynamic_forward_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nKio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3B\033SniDynamicForwardProxyProtoP\001Z\200\001github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3;sni_dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG.fields_by_name['dns_cache_config']._options = None
  _FILTERCONFIG.fields_by_name['dns_cache_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FILTERCONFIG.fields_by_name['port_value']._options = None
  _FILTERCONFIG.fields_by_name['port_value']._serialized_options = b'\372B\010*\006\030\377\377\003 \000'
  _globals['_FILTERCONFIG']._serialized_start=283
  _globals['_FILTERCONFIG']._serialized_end=452
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v3/accesslog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.data.accesslog.v3 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.type.matcher.v3 import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_metadata__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/accesslog/v3/accesslog.proto\x12\x19\x65nvoy.config.accesslog.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\'envoy/data/accesslog/v3/accesslog.proto\x1a$envoy/type/matcher/v3/metadata.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd3\x01\n\tAccessLog\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x06\x66ilter\x18\x02 \x01(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilter\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:1\x9a\xc5\x88\x1e,\n*envoy.config.filter.accesslog.v2.AccessLogB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04R\x06\x63onfig\"\xf9\x07\n\x0f\x41\x63\x63\x65ssLogFilter\x12I\n\x12status_code_filter\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.StatusCodeFilterH\x00\x12\x44\n\x0f\x64uration_filter\x18\x02 \x01(\x0b\x32).envoy.config.accesslog.v3.DurationFilterH\x00\x12R\n\x17not_health_check_filter\x18\x03 \x01(\x0b\x32/.envoy.config.accesslog.v3.NotHealthCheckFilterH\x00\x12\x46\n\x10traceable_filter\x18\x04 \x01(\x0b\x32*.envoy.config.accesslog.v3.TraceableFilterH\x00\x12\x42\n\x0eruntime_filter\x18\x05 \x01(\x0b\x32(.envoy.config.accesslog.v3.RuntimeFilterH\x00\x12:\n\nand_filter\x18\x06 \x01(\x0b\x32$.envoy.config.accesslog.v3.AndFilterH\x00\x12\x38\n\tor_filter\x18\x07 \x01(\x0b\x32#.envoy.config.accesslog.v3.OrFilterH\x00\x12@\n\rheader_filter\x18\x08 \x01(\x0b\x32\'.envoy.config.accesslog.v3.HeaderFilterH\x00\x12M\n\x14response_flag_filter\x18\t \x01(\x0b\x32-.envoy.config.accesslog.v3.ResponseFlagFilterH\x00\x12I\n\x12grpc_status_filter\x18\n \x01(\x0b\x32+.envoy.config.accesslog.v3.GrpcStatusFilterH\x00\x12\x46\n\x10\x65xtension_filter\x18\x0b \x01(\x0b\x32*.envoy.config.accesslog.v3.ExtensionFilterH\x00\x12\x44\n\x0fmetadata_filter\x18\x0c \x01(\x0b\x32).envoy.config.accesslog.v3.MetadataFilterH\x00\x12\x43\n\x0flog_type_filter\x18\r \x01(\x0b\x32(.envoy.config.accesslog.v3.LogTypeFilterH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.AccessLogFilterB\x17\n\x10\x66ilter_specifier\x12\x03\xf8\x42\x01\"\xee\x01\n\x10\x43omparisonFilter\x12\x44\n\x02op\x18\x01 \x01(\x0e\x32..envoy.config.accesslog.v3.ComparisonFilter.OpB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x05value\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeUInt32B\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1c\n\x02Op\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.ComparisonFilter\"\x97\x01\n\x10StatusCodeFilter\x12I\n\ncomparison\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.StatusCodeFilter\"\x93\x01\n\x0e\x44urationFilter\x12I\n\ncomparison\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:6\x9a\xc5\x88\x1e\x31\n/envoy.config.filter.accesslog.v2.DurationFilter\"T\n\x14NotHealthCheckFilter:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.accesslog.v2.NotHealthCheckFilter\"J\n\x0fTraceableFilter:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.TraceableFilter\"\xc3\x01\n\rRuntimeFilter\x12\x1c\n\x0bruntime_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0fpercent_sampled\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\"\n\x1ause_independent_randomness\x18\x03 \x01(\x08:5\x9a\xc5\x88\x1e\x30\n.envoy.config.filter.accesslog.v2.RuntimeFilter\"\x85\x01\n\tAndFilter\x12\x45\n\x07\x66ilters\x18\x01 \x03(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:1\x9a\xc5\x88\x1e,\n*envoy.config.filter.accesslog.v2.AndFilter\"\x83\x01\n\x08OrFilter\x12\x45\n\x07\x66ilters\x18\x02 \x03(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.accesslog.v2.OrFilter\"\x84\x01\n\x0cHeaderFilter\x12>\n\x06header\x18\x01 \x01(\x0b\x32$.envoy.config.route.v3.HeaderMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:4\x9a\xc5\x88\x1e/\n-envoy.config.filter.accesslog.v2.HeaderFilter\"\xee\x01\n\x12ResponseFlagFilter\x12\x9b\x01\n\x05\x66lags\x18\x01 \x03(\tB\x8b\x01\xfa\x42\x87\x01\x92\x01\x83\x01\"\x80\x01r~R\x02LHR\x02UHR\x02UTR\x02LRR\x02URR\x02UFR\x02UCR\x02UOR\x02NRR\x02\x44IR\x02\x46IR\x02RLR\x04UAEXR\x04RLSER\x02\x44\x43R\x03URXR\x02SIR\x02IHR\x03\x44PER\x05UMSDRR\x04RFCFR\x04NFCFR\x02\x44TR\x03UPER\x02NCR\x02OMR\x02\x44\x46R\x02\x44O::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.accesslog.v2.ResponseFlagFilter\"\xed\x03\n\x10GrpcStatusFilter\x12S\n\x08statuses\x18\x01 \x03(\x0e\x32\x32.envoy.config.accesslog.v3.GrpcStatusFilter.StatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xb8\x02\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.GrpcStatusFilter\"\xbd\x01\n\x0eMetadataFilter\x12\x37\n\x07matcher\x18\x01 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcher\x12:\n\x16match_if_key_not_found\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:6\x9a\xc5\x88\x1e\x31\n/envoy.config.filter.accesslog.v2.MetadataFilter\"f\n\rLogTypeFilter\x12\x44\n\x05types\x18\x01 \x03(\x0e\x32&.envoy.data.accesslog.v3.AccessLogTypeB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xa3\x01\n\x0f\x45xtensionFilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.ExtensionFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigB\x91\x01\n\'io.envoyproxy.envoy.config.accesslog.v3B\x0e\x41\x63\x63\x65sslogProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v3;accesslogv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.accesslog.v3.accesslog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.config.accesslog.v3B\016AccesslogProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v3;accesslogv3\272\200\310\321\006\002\020\002'
  _ACCESSLOG._options = None
  _ACCESSLOG._serialized_options = b'\232\305\210\036,\n*envoy.config.filter.accesslog.v2.AccessLog'
  _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._options = None
  _ACCESSLOGFILTER.oneofs_by_name['filter_specifier']._serialized_options = b'\370B\001'
  _ACCESSLOGFILTER._options = None
  _ACCESSLOGFILTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.AccessLogFilter'
  _COMPARISONFILTER.fields_by_name['op']._options = None
  _COMPARISONFILTER.fields_by_name['op']._serialized_options = b'\372B\005\202\001\002\020\001'
  _COMPARISONFILTER.fields_by_name['value']._options = None
  _COMPARISONFILTER.fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMPARISONFILTER._options = None
  _COMPARISONFILTER._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.ComparisonFilter'
  _STATUSCODEFILTER.fields_by_name['comparison']._options = None
  _STATUSCODEFILTER.fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STATUSCODEFILTER._options = None
  _STATUSCODEFILTER._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.StatusCodeFilter'
  _DURATIONFILTER.fields_by_name['comparison']._options = None
  _DURATIONFILTER.fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DURATIONFILTER._options = None
  _DURATIONFILTER._serialized_options = b'\232\305\210\0361\n/envoy.config.filter.accesslog.v2.DurationFilter'
  _NOTHEALTHCHECKFILTER._options = None
  _NOTHEALTHCHECKFILTER._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.accesslog.v2.NotHealthCheckFilter'
  _TRACEABLEFILTER._options = None
  _TRACEABLEFILTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.TraceableFilter'
  _RUNTIMEFILTER.fields_by_name['runtime_key']._options = None
  _RUNTIMEFILTER.fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002\020\001'
  _RUNTIMEFILTER._options = None
  _RUNTIMEFILTER._serialized_options = b'\232\305\210\0360\n.envoy.config.filter.accesslog.v2.RuntimeFilter'
  _ANDFILTER.fields_by_name['filters']._options = None
  _ANDFILTER.fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _ANDFILTER._options = None
  _ANDFILTER._serialized_options = b'\232\305\210\036,\n*envoy.config.filter.accesslog.v2.AndFilter'
  _ORFILTER.fields_by_name['filters']._options = None
  _ORFILTER.fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _ORFILTER._options = None
  _ORFILTER._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.accesslog.v2.OrFilter'
  _HEADERFILTER.fields_by_name['header']._options = None
  _HEADERFILTER.fields_by_name['header']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEADERFILTER._options = None
  _HEADERFILTER._serialized_options = b'\232\305\210\036/\n-envoy.config.filter.accesslog.v2.HeaderFilter'
  _RESPONSEFLAGFILTER.fields_by_name['flags']._options = None
  _RESPONSEFLAGFILTER.fields_by_name['flags']._serialized_options = b'\372B\207\001\222\001\203\001\"\200\001r~R\002LHR\002UHR\002UTR\002LRR\002URR\002UFR\002UCR\002UOR\002NRR\002DIR\002FIR\002RLR\004UAEXR\004RLSER\002DCR\003URXR\002SIR\002IHR\003DPER\005UMSDRR\004RFCFR\004NFCFR\002DTR\003UPER\002NCR\002OMR\002DFR\002DO'
  _RESPONSEFLAGFILTER._options = None
  _RESPONSEFLAGFILTER._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.accesslog.v2.ResponseFlagFilter'
  _GRPCSTATUSFILTER.fields_by_name['statuses']._options = None
  _GRPCSTATUSFILTER.fields_by_name['statuses']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _GRPCSTATUSFILTER._options = None
  _GRPCSTATUSFILTER._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.GrpcStatusFilter'
  _METADATAFILTER._options = None
  _METADATAFILTER._serialized_options = b'\232\305\210\0361\n/envoy.config.filter.accesslog.v2.MetadataFilter'
  _LOGTYPEFILTER.fields_by_name['types']._options = None
  _LOGTYPEFILTER.fields_by_name['types']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _EXTENSIONFILTER._options = None
  _EXTENSIONFILTER._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.ExtensionFilter'
  _globals['_ACCESSLOG']._serialized_start=410
  _globals['_ACCESSLOG']._serialized_end=621
  _globals['_ACCESSLOGFILTER']._serialized_start=624
  _globals['_ACCESSLOGFILTER']._serialized_end=1641
  _globals['_COMPARISONFILTER']._serialized_start=1644
  _globals['_COMPARISONFILTER']._serialized_end=1882
  _globals['_COMPARISONFILTER_OP']._serialized_start=1796
  _globals['_COMPARISONFILTER_OP']._serialized_end=1824
  _globals['_STATUSCODEFILTER']._serialized_start=1885
  _globals['_STATUSCODEFILTER']._serialized_end=2036
  _globals['_DURATIONFILTER']._serialized_start=2039
  _globals['_DURATIONFILTER']._serialized_end=2186
  _globals['_NOTHEALTHCHECKFILTER']._serialized_start=2188
  _globals['_NOTHEALTHCHECKFILTER']._serialized_end=2272
  _globals['_TRACEABLEFILTER']._serialized_start=2274
  _globals['_TRACEABLEFILTER']._serialized_end=2348
  _globals['_RUNTIMEFILTER']._serialized_start=2351
  _globals['_RUNTIMEFILTER']._serialized_end=2546
  _globals['_ANDFILTER']._serialized_start=2549
  _globals['_ANDFILTER']._serialized_end=2682
  _globals['_ORFILTER']._serialized_start=2685
  _globals['_ORFILTER']._serialized_end=2816
  _globals['_HEADERFILTER']._serialized_start=2819
  _globals['_HEADERFILTER']._serialized_end=2951
  _globals['_RESPONSEFLAGFILTER']._serialized_start=2954
  _globals['_RESPONSEFLAGFILTER']._serialized_end=3192
  _globals['_GRPCSTATUSFILTER']._serialized_start=3195
  _globals['_GRPCSTATUSFILTER']._serialized_end=3688
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_start=3318
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_end=3630
  _globals['_METADATAFILTER']._serialized_start=3691
  _globals['_METADATAFILTER']._serialized_end=3880
  _globals['_LOGTYPEFILTER']._serialized_start=3882
  _globals['_LOGTYPEFILTER']._serialized_end=3984
  _globals['_EXTENSIONFILTER']._serialized_start=3987
  _globals['_EXTENSIONFILTER']._serialized_end=4150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/v2/logging_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/logging/v2/logging_config.proto\x12\x11google.logging.v2\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\xae\x04\n\tLogBucket\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x35\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x16\n\x0eretention_days\x18\x0b \x01(\x05\x12\x0e\n\x06locked\x18\t \x01(\x08\x12@\n\x0flifecycle_state\x18\x0c \x01(\x0e\x32!.google.logging.v2.LifecycleStateB\x04\xe2\x41\x01\x03:\xa5\x02\xea\x41\xa1\x02\n logging.googleapis.com/LogBucket\x12\x38projects/{project}/locations/{location}/buckets/{bucket}\x12\x42organizations/{organization}/locations/{location}/buckets/{bucket}\x12\x36\x66olders/{folder}/locations/{location}/buckets/{bucket}\x12GbillingAccounts/{billing_account}/locations/{location}/buckets/{bucket}\"\x84\x04\n\x07LogView\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x35\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x0e\n\x06\x66ilter\x18\x07 \x01(\t:\xd7\x02\xea\x41\xd3\x02\n\x1elogging.googleapis.com/LogView\x12\x45projects/{project}/locations/{location}/buckets/{bucket}/views/{view}\x12Oorganizations/{organization}/locations/{location}/buckets/{bucket}/views/{view}\x12\x43\x66olders/{folder}/locations/{location}/buckets/{bucket}/views/{view}\x12TbillingAccounts/{billing_account}/locations/{location}/buckets/{bucket}/views/{view}\"\x90\x06\n\x07LogSink\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1f\n\x0b\x64\x65stination\x18\x03 \x01(\tB\n\xe2\x41\x01\x02\xfa\x41\x03\n\x01*\x12\x14\n\x06\x66ilter\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x12 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08\x64isabled\x18\x13 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x39\n\nexclusions\x18\x10 \x03(\x0b\x32\x1f.google.logging.v2.LogExclusionB\x04\xe2\x41\x01\x01\x12K\n\x15output_version_format\x18\x06 \x01(\x0e\x32(.google.logging.v2.LogSink.VersionFormatB\x02\x18\x01\x12\x1d\n\x0fwriter_identity\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03\x12\x1e\n\x10include_children\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x44\n\x10\x62igquery_options\x18\x0c \x01(\x0b\x32\".google.logging.v2.BigQueryOptionsB\x04\xe2\x41\x01\x01H\x00\x12\x35\n\x0b\x63reate_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\"?\n\rVersionFormat\x12\x1e\n\x1aVERSION_FORMAT_UNSPECIFIED\x10\x00\x12\x06\n\x02V2\x10\x01\x12\x06\n\x02V1\x10\x02:\xbf\x01\xea\x41\xbb\x01\n\x1elogging.googleapis.com/LogSink\x12\x1fprojects/{project}/sinks/{sink}\x12)organizations/{organization}/sinks/{sink}\x12\x1d\x66olders/{folder}/sinks/{sink}\x12.billingAccounts/{billing_account}/sinks/{sink}B\t\n\x07options\"i\n\x0f\x42igQueryOptions\x12$\n\x16use_partitioned_tables\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x30\n\"uses_timestamp_column_partitioning\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x03\"\x82\x01\n\x12ListBucketsRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 logging.googleapis.com/LogBucket\x12\x18\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"]\n\x13ListBucketsResponse\x12-\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x1c.google.logging.v2.LogBucket\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9d\x01\n\x13\x43reateBucketRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 logging.googleapis.com/LogBucket\x12\x17\n\tbucket_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12\x32\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x1c.google.logging.v2.LogBucketB\x04\xe2\x41\x01\x02\"\xb9\x01\n\x13UpdateBucketRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogBucket\x12\x32\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x1c.google.logging.v2.LogBucketB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02\"K\n\x10GetBucketRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogBucket\"N\n\x13\x44\x65leteBucketRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogBucket\"P\n\x15UndeleteBucketRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n logging.googleapis.com/LogBucket\"[\n\x10ListViewsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x18\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"W\n\x11ListViewsResponse\x12)\n\x05views\x18\x01 \x03(\x0b\x32\x1a.google.logging.v2.LogView\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"p\n\x11\x43reateViewRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x15\n\x07view_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02\x12.\n\x04view\x18\x03 \x01(\x0b\x32\x1a.google.logging.v2.LogViewB\x04\xe2\x41\x01\x02\"\x8e\x01\n\x11UpdateViewRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12.\n\x04view\x18\x02 \x01(\x0b\x32\x1a.google.logging.v2.LogViewB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"G\n\x0eGetViewRequest\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1elogging.googleapis.com/LogView\"J\n\x11\x44\x65leteViewRequest\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1elogging.googleapis.com/LogView\"~\n\x10ListSinksRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \x12\x1elogging.googleapis.com/LogSink\x12\x18\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"W\n\x11ListSinksResponse\x12)\n\x05sinks\x18\x01 \x03(\x0b\x32\x1a.google.logging.v2.LogSink\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\x0eGetSinkRequest\x12:\n\tsink_name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1elogging.googleapis.com/LogSink\"\xa2\x01\n\x11\x43reateSinkRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \x12\x1elogging.googleapis.com/LogSink\x12.\n\x04sink\x18\x02 \x01(\x0b\x32\x1a.google.logging.v2.LogSinkB\x04\xe2\x41\x01\x02\x12$\n\x16unique_writer_identity\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\"\xdc\x01\n\x11UpdateSinkRequest\x12:\n\tsink_name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1elogging.googleapis.com/LogSink\x12.\n\x04sink\x18\x02 \x01(\x0b\x32\x1a.google.logging.v2.LogSinkB\x04\xe2\x41\x01\x02\x12$\n\x16unique_writer_identity\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x35\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"O\n\x11\x44\x65leteSinkRequest\x12:\n\tsink_name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1elogging.googleapis.com/LogSink\"\xc8\x03\n\x0cLogExclusion\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x19\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02\x12\x16\n\x08\x64isabled\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x35\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:\xec\x01\xea\x41\xe8\x01\n#logging.googleapis.com/LogExclusion\x12)projects/{project}/exclusions/{exclusion}\x12\x33organizations/{organization}/exclusions/{exclusion}\x12\'folders/{folder}/exclusions/{exclusion}\x12\x38\x62illingAccounts/{billing_account}/exclusions/{exclusion}\"\x88\x01\n\x15ListExclusionsRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\x12#logging.googleapis.com/LogExclusion\x12\x18\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x17\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01\"f\n\x16ListExclusionsResponse\x12\x33\n\nexclusions\x18\x01 \x03(\x0b\x32\x1f.google.logging.v2.LogExclusion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x13GetExclusionRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#logging.googleapis.com/LogExclusion\"\x90\x01\n\x16\x43reateExclusionRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\x12#logging.googleapis.com/LogExclusion\x12\x38\n\texclusion\x18\x02 \x01(\x0b\x32\x1f.google.logging.v2.LogExclusionB\x04\xe2\x41\x01\x02\"\xc5\x01\n\x16UpdateExclusionRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#logging.googleapis.com/LogExclusion\x12\x38\n\texclusion\x18\x02 \x01(\x0b\x32\x1f.google.logging.v2.LogExclusionB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x02\"T\n\x16\x44\x65leteExclusionRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#logging.googleapis.com/LogExclusion\"T\n\x16GetCmekSettingsRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#logging.googleapis.com/CmekSettings\"\xa4\x01\n\x19UpdateCmekSettingsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12<\n\rcmek_settings\x18\x02 \x01(\x0b\x32\x1f.google.logging.v2.CmekSettingsB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\xa1\x02\n\x0c\x43mekSettings\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03\x12\x14\n\x0ckms_key_name\x18\x02 \x01(\t\x12 \n\x12service_account_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03:\xc4\x01\xea\x41\xc0\x01\n#logging.googleapis.com/CmekSettings\x12\x1fprojects/{project}/cmekSettings\x12)organizations/{organization}/cmekSettings\x12\x1d\x66olders/{folder}/cmekSettings\x12.billingAccounts/{billing_account}/cmekSettings*S\n\x0eLifecycleState\x12\x1f\n\x1bLIFECYCLE_STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x14\n\x10\x44\x45LETE_REQUESTED\x10\x02\x32\xdc>\n\x0f\x43onfigServiceV2\x12\xdc\x02\n\x0bListBuckets\x12%.google.logging.v2.ListBucketsRequest\x1a&.google.logging.v2.ListBucketsResponse\"\xfd\x01\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xed\x01\x12$/v2/{parent=*/*/locations/*}/bucketsZ-\x12+/v2/{parent=projects/*/locations/*}/bucketsZ2\x12\x30/v2/{parent=organizations/*/locations/*}/bucketsZ,\x12*/v2/{parent=folders/*/locations/*}/bucketsZ4\x12\x32/v2/{parent=billingAccounts/*/locations/*}/buckets\x12\xb9\x02\n\tGetBucket\x12#.google.logging.v2.GetBucketRequest\x1a\x1c.google.logging.v2.LogBucket\"\xe8\x01\x82\xd3\xe4\x93\x02\xe1\x01\x12$/v2/{name=*/*/locations/*/buckets/*}Z-\x12+/v2/{name=projects/*/locations/*/buckets/*}Z2\x12\x30/v2/{name=organizations/*/locations/*/buckets/*}Z,\x12*/v2/{name=folders/*/locations/*/buckets/*}Z(\x12&/v2/{name=billingAccounts/*/buckets/*}\x12\xf3\x02\n\x0c\x43reateBucket\x12&.google.logging.v2.CreateBucketRequest\x1a\x1c.google.logging.v2.LogBucket\"\x9c\x02\x82\xd3\xe4\x93\x02\x95\x02\"$/v2/{parent=*/*/locations/*}/buckets:\x06\x62ucketZ5\"+/v2/{parent=projects/*/locations/*}/buckets:\x06\x62ucketZ:\"0/v2/{parent=organizations/*/locations/*}/buckets:\x06\x62ucketZ4\"*/v2/{parent=folders/*/locations/*}/buckets:\x06\x62ucketZ<\"2/v2/{parent=billingAccounts/*/locations/*}/buckets:\x06\x62ucket\x12\xf3\x02\n\x0cUpdateBucket\x12&.google.logging.v2.UpdateBucketRequest\x1a\x1c.google.logging.v2.LogBucket\"\x9c\x02\x82\xd3\xe4\x93\x02\x95\x02\x32$/v2/{name=*/*/locations/*/buckets/*}:\x06\x62ucketZ52+/v2/{name=projects/*/locations/*/buckets/*}:\x06\x62ucketZ:20/v2/{name=organizations/*/locations/*/buckets/*}:\x06\x62ucketZ42*/v2/{name=folders/*/locations/*/buckets/*}:\x06\x62ucketZ<22/v2/{name=billingAccounts/*/locations/*/buckets/*}:\x06\x62ucket\x12\xc5\x02\n\x0c\x44\x65leteBucket\x12&.google.logging.v2.DeleteBucketRequest\x1a\x16.google.protobuf.Empty\"\xf4\x01\x82\xd3\xe4\x93\x02\xed\x01*$/v2/{name=*/*/locations/*/buckets/*}Z-*+/v2/{name=projects/*/locations/*/buckets/*}Z2*0/v2/{name=organizations/*/locations/*/buckets/*}Z,**/v2/{name=folders/*/locations/*/buckets/*}Z4*2/v2/{name=billingAccounts/*/locations/*/buckets/*}\x12\x85\x03\n\x0eUndeleteBucket\x12(.google.logging.v2.UndeleteBucketRequest\x1a\x16.google.protobuf.Empty\"\xb0\x02\x82\xd3\xe4\x93\x02\xa9\x02\"-/v2/{name=*/*/locations/*/buckets/*}:undelete:\x01*Z9\"4/v2/{name=projects/*/locations/*/buckets/*}:undelete:\x01*Z>\"9/v2/{name=organizations/*/locations/*/buckets/*}:undelete:\x01*Z8\"3/v2/{name=folders/*/locations/*/buckets/*}:undelete:\x01*Z@\";/v2/{name=billingAccounts/*/locations/*/buckets/*}:undelete:\x01*\x12\xfe\x02\n\tListViews\x12#.google.logging.v2.ListViewsRequest\x1a$.google.logging.v2.ListViewsResponse\"\xa5\x02\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x95\x02\x12,/v2/{parent=*/*/locations/*/buckets/*}/viewsZ5\x12\x33/v2/{parent=projects/*/locations/*/buckets/*}/viewsZ:\x12\x38/v2/{parent=organizations/*/locations/*/buckets/*}/viewsZ4\x12\x32/v2/{parent=folders/*/locations/*/buckets/*}/viewsZ<\x12:/v2/{parent=billingAccounts/*/locations/*/buckets/*}/views\x12\xdb\x02\n\x07GetView\x12!.google.logging.v2.GetViewRequest\x1a\x1a.google.logging.v2.LogView\"\x90\x02\x82\xd3\xe4\x93\x02\x89\x02\x12,/v2/{name=*/*/locations/*/buckets/*/views/*}Z5\x12\x33/v2/{name=projects/*/locations/*/buckets/*/views/*}Z:\x12\x38/v2/{name=organizations/*/locations/*/buckets/*/views/*}Z4\x12\x32/v2/{name=folders/*/locations/*/buckets/*/views/*}Z0\x12./v2/{name=billingAccounts/*/buckets/*/views/*}\x12\x8b\x03\n\nCreateView\x12$.google.logging.v2.CreateViewRequest\x1a\x1a.google.logging.v2.LogView\"\xba\x02\x82\xd3\xe4\x93\x02\xb3\x02\",/v2/{parent=*/*/locations/*/buckets/*}/views:\x04viewZ;\"3/v2/{parent=projects/*/locations/*/buckets/*}/views:\x04viewZ@\"8/v2/{parent=organizations/*/locations/*/buckets/*}/views:\x04viewZ:\"2/v2/{parent=folders/*/locations/*/buckets/*}/views:\x04viewZB\":/v2/{parent=billingAccounts/*/locations/*/buckets/*}/views:\x04view\x12\x8b\x03\n\nUpdateView\x12$.google.logging.v2.UpdateViewRequest\x1a\x1a.google.logging.v2.LogView\"\xba\x02\x82\xd3\xe4\x93\x02\xb3\x02\x32,/v2/{name=*/*/locations/*/buckets/*/views/*}:\x04viewZ;23/v2/{name=projects/*/locations/*/buckets/*/views/*}:\x04viewZ@28/v2/{name=organizations/*/locations/*/buckets/*/views/*}:\x04viewZ:22/v2/{name=folders/*/locations/*/buckets/*/views/*}:\x04viewZB2:/v2/{name=billingAccounts/*/locations/*/buckets/*/views/*}:\x04view\x12\xe9\x02\n\nDeleteView\x12$.google.logging.v2.DeleteViewRequest\x1a\x16.google.protobuf.Empty\"\x9c\x02\x82\xd3\xe4\x93\x02\x95\x02*,/v2/{name=*/*/locations/*/buckets/*/views/*}Z5*3/v2/{name=projects/*/locations/*/buckets/*/views/*}Z:*8/v2/{name=organizations/*/locations/*/buckets/*/views/*}Z4*2/v2/{name=folders/*/locations/*/buckets/*/views/*}Z<*:/v2/{name=billingAccounts/*/locations/*/buckets/*/views/*}\x12\x90\x02\n\tListSinks\x12#.google.logging.v2.ListSinksRequest\x1a$.google.logging.v2.ListSinksResponse\"\xb7\x01\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xa7\x01\x12\x16/v2/{parent=*/*}/sinksZ\x1f\x12\x1d/v2/{parent=projects/*}/sinksZ$\x12\"/v2/{parent=organizations/*}/sinksZ\x1e\x12\x1c/v2/{parent=folders/*}/sinksZ&\x12$/v2/{parent=billingAccounts/*}/sinks\x12\x9e\x02\n\x07GetSink\x12!.google.logging.v2.GetSinkRequest\x1a\x1a.google.logging.v2.LogSink\"\xd3\x01\xda\x41\tsink_name\x82\xd3\xe4\x93\x02\xc0\x01\x12\x1b/v2/{sink_name=*/*/sinks/*}Z$\x12\"/v2/{sink_name=projects/*/sinks/*}Z)\x12\'/v2/{sink_name=organizations/*/sinks/*}Z#\x12!/v2/{sink_name=folders/*/sinks/*}Z+\x12)/v2/{sink_name=billingAccounts/*/sinks/*}\x12\xab\x02\n\nCreateSink\x12$.google.logging.v2.CreateSinkRequest\x1a\x1a.google.logging.v2.LogSink\"\xda\x01\xda\x41\x0bparent,sink\x82\xd3\xe4\x93\x02\xc5\x01\"\x16/v2/{parent=*/*}/sinks:\x04sinkZ%\"\x1d/v2/{parent=projects/*}/sinks:\x04sinkZ*\"\"/v2/{parent=organizations/*}/sinks:\x04sinkZ$\"\x1c/v2/{parent=folders/*}/sinks:\x04sinkZ,\"$/v2/{parent=billingAccounts/*}/sinks:\x04sink\x12\x9f\x04\n\nUpdateSink\x12$.google.logging.v2.UpdateSinkRequest\x1a\x1a.google.logging.v2.LogSink\"\xce\x03\xda\x41\x1asink_name,sink,update_mask\xda\x41\x0esink_name,sink\x82\xd3\xe4\x93\x02\x99\x03\x1a\x1b/v2/{sink_name=*/*/sinks/*}:\x04sinkZ*\x1a\"/v2/{sink_name=projects/*/sinks/*}:\x04sinkZ/\x1a\'/v2/{sink_name=organizations/*/sinks/*}:\x04sinkZ)\x1a!/v2/{sink_name=folders/*/sinks/*}:\x04sinkZ1\x1a)/v2/{sink_name=billingAccounts/*/sinks/*}:\x04sinkZ*2\"/v2/{sink_name=projects/*/sinks/*}:\x04sinkZ/2\'/v2/{sink_name=organizations/*/sinks/*}:\x04sinkZ)2!/v2/{sink_name=folders/*/sinks/*}:\x04sinkZ12)/v2/{sink_name=billingAccounts/*/sinks/*}:\x04sink\x12\xa0\x02\n\nDeleteSink\x12$.google.logging.v2.DeleteSinkRequest\x1a\x16.google.protobuf.Empty\"\xd3\x01\xda\x41\tsink_name\x82\xd3\xe4\x93\x02\xc0\x01*\x1b/v2/{sink_name=*/*/sinks/*}Z$*\"/v2/{sink_name=projects/*/sinks/*}Z)*\'/v2/{sink_name=organizations/*/sinks/*}Z#*!/v2/{sink_name=folders/*/sinks/*}Z+*)/v2/{sink_name=billingAccounts/*/sinks/*}\x12\xb8\x02\n\x0eListExclusions\x12(.google.logging.v2.ListExclusionsRequest\x1a).google.logging.v2.ListExclusionsResponse\"\xd0\x01\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xc0\x01\x12\x1b/v2/{parent=*/*}/exclusionsZ$\x12\"/v2/{parent=projects/*}/exclusionsZ)\x12\'/v2/{parent=organizations/*}/exclusionsZ#\x12!/v2/{parent=folders/*}/exclusionsZ+\x12)/v2/{parent=billingAccounts/*}/exclusions\x12\xa8\x02\n\x0cGetExclusion\x12&.google.logging.v2.GetExclusionRequest\x1a\x1f.google.logging.v2.LogExclusion\"\xce\x01\xda\x41\x04name\x82\xd3\xe4\x93\x02\xc0\x01\x12\x1b/v2/{name=*/*/exclusions/*}Z$\x12\"/v2/{name=projects/*/exclusions/*}Z)\x12\'/v2/{name=organizations/*/exclusions/*}Z#\x12!/v2/{name=folders/*/exclusions/*}Z+\x12)/v2/{name=billingAccounts/*/exclusions/*}\x12\xf1\x02\n\x0f\x43reateExclusion\x12).google.logging.v2.CreateExclusionRequest\x1a\x1f.google.logging.v2.LogExclusion\"\x91\x02\xda\x41\x10parent,exclusion\x82\xd3\xe4\x93\x02\xf7\x01\"\x1b/v2/{parent=*/*}/exclusions:\texclusionZ/\"\"/v2/{parent=projects/*}/exclusions:\texclusionZ4\"\'/v2/{parent=organizations/*}/exclusions:\texclusionZ.\"!/v2/{parent=folders/*}/exclusions:\texclusionZ6\")/v2/{parent=billingAccounts/*}/exclusions:\texclusion\x12\xfb\x02\n\x0fUpdateExclusion\x12).google.logging.v2.UpdateExclusionRequest\x1a\x1f.google.logging.v2.LogExclusion\"\x9b\x02\xda\x41\x1aname,exclusion,update_mask\x82\xd3\xe4\x93\x02\xf7\x01\x32\x1b/v2/{name=*/*/exclusions/*}:\texclusionZ/2\"/v2/{name=projects/*/exclusions/*}:\texclusionZ42\'/v2/{name=organizations/*/exclusions/*}:\texclusionZ.2!/v2/{name=folders/*/exclusions/*}:\texclusionZ62)/v2/{name=billingAccounts/*/exclusions/*}:\texclusion\x12\xa5\x02\n\x0f\x44\x65leteExclusion\x12).google.logging.v2.DeleteExclusionRequest\x1a\x16.google.protobuf.Empty\"\xce\x01\xda\x41\x04name\x82\xd3\xe4\x93\x02\xc0\x01*\x1b/v2/{name=*/*/exclusions/*}Z$*\"/v2/{name=projects/*/exclusions/*}Z)*\'/v2/{name=organizations/*/exclusions/*}Z#*!/v2/{name=folders/*/exclusions/*}Z+*)/v2/{name=billingAccounts/*/exclusions/*}\x12\xad\x01\n\x0fGetCmekSettings\x12).google.logging.v2.GetCmekSettingsRequest\x1a\x1f.google.logging.v2.CmekSettings\"N\x82\xd3\xe4\x93\x02H\x12\x1b/v2/{name=*/*}/cmekSettingsZ)\x12\'/v2/{name=organizations/*}/cmekSettings\x12\xd1\x01\n\x12UpdateCmekSettings\x12,.google.logging.v2.UpdateCmekSettingsRequest\x1a\x1f.google.logging.v2.CmekSettings\"l\x82\xd3\xe4\x93\x02\x66\x32\x1b/v2/{name=*/*}/cmekSettings:\rcmek_settingsZ82\'/v2/{name=organizations/*}/cmekSettings:\rcmek_settings\x1a\xdf\x01\xca\x41\x16logging.googleapis.com\xd2\x41\xc2\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.readB\xd9\x03\n\x15\x63om.google.logging.v2B\x12LoggingConfigProtoP\x01Z8google.golang.org/genproto/googleapis/logging/v2;logging\xf8\x01\x01\xaa\x02\x17Google.Cloud.Logging.V2\xca\x02\x17Google\\Cloud\\Logging\\V2\xea\x02\x1aGoogle::Cloud::Logging::V2\xea\x41`\n+logging.googleapis.com/OrganizationLocation\x12\x31organizations/{organization}/locations/{location}\xea\x41N\n%logging.googleapis.com/FolderLocation\x12%folders/{folder}/locations/{location}\xea\x41g\n-logging.googleapis.com/BillingAccountLocation\x12\x36\x62illingAccounts/{billing_account}/locations/{location}b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.logging.v2.logging_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.google.logging.v2B\022LoggingConfigProtoP\001Z8google.golang.org/genproto/googleapis/logging/v2;logging\370\001\001\252\002\027Google.Cloud.Logging.V2\312\002\027Google\\Cloud\\Logging\\V2\352\002\032Google::Cloud::Logging::V2\352A`\n+logging.googleapis.com/OrganizationLocation\0221organizations/{organization}/locations/{location}\352AN\n%logging.googleapis.com/FolderLocation\022%folders/{folder}/locations/{location}\352Ag\n-logging.googleapis.com/BillingAccountLocation\0226billingAccounts/{billing_account}/locations/{location}'
  _LOGBUCKET.fields_by_name['create_time']._options = None
  _LOGBUCKET.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _LOGBUCKET.fields_by_name['update_time']._options = None
  _LOGBUCKET.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _LOGBUCKET.fields_by_name['lifecycle_state']._options = None
  _LOGBUCKET.fields_by_name['lifecycle_state']._serialized_options = b'\342A\001\003'
  _LOGBUCKET._options = None
  _LOGBUCKET._serialized_options = b'\352A\241\002\n logging.googleapis.com/LogBucket\0228projects/{project}/locations/{location}/buckets/{bucket}\022Borganizations/{organization}/locations/{location}/buckets/{bucket}\0226folders/{folder}/locations/{location}/buckets/{bucket}\022GbillingAccounts/{billing_account}/locations/{location}/buckets/{bucket}'
  _LOGVIEW.fields_by_name['create_time']._options = None
  _LOGVIEW.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _LOGVIEW.fields_by_name['update_time']._options = None
  _LOGVIEW.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _LOGVIEW._options = None
  _LOGVIEW._serialized_options = b'\352A\323\002\n\036logging.googleapis.com/LogView\022Eprojects/{project}/locations/{location}/buckets/{bucket}/views/{view}\022Oorganizations/{organization}/locations/{location}/buckets/{bucket}/views/{view}\022Cfolders/{folder}/locations/{location}/buckets/{bucket}/views/{view}\022TbillingAccounts/{billing_account}/locations/{location}/buckets/{bucket}/views/{view}'
  _LOGSINK.fields_by_name['name']._options = None
  _LOGSINK.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _LOGSINK.fields_by_name['destination']._options = None
  _LOGSINK.fields_by_name['destination']._serialized_options = b'\342A\001\002\372A\003\n\001*'
  _LOGSINK.fields_by_name['filter']._options = None
  _LOGSINK.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LOGSINK.fields_by_name['description']._options = None
  _LOGSINK.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _LOGSINK.fields_by_name['disabled']._options = None
  _LOGSINK.fields_by_name['disabled']._serialized_options = b'\342A\001\001'
  _LOGSINK.fields_by_name['exclusions']._options = None
  _LOGSINK.fields_by_name['exclusions']._serialized_options = b'\342A\001\001'
  _LOGSINK.fields_by_name['output_version_format']._options = None
  _LOGSINK.fields_by_name['output_version_format']._serialized_options = b'\030\001'
  _LOGSINK.fields_by_name['writer_identity']._options = None
  _LOGSINK.fields_by_name['writer_identity']._serialized_options = b'\342A\001\003'
  _LOGSINK.fields_by_name['include_children']._options = None
  _LOGSINK.fields_by_name['include_children']._serialized_options = b'\342A\001\001'
  _LOGSINK.fields_by_name['bigquery_options']._options = None
  _LOGSINK.fields_by_name['bigquery_options']._serialized_options = b'\342A\001\001'
  _LOGSINK.fields_by_name['create_time']._options = None
  _LOGSINK.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _LOGSINK.fields_by_name['update_time']._options = None
  _LOGSINK.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _LOGSINK._options = None
  _LOGSINK._serialized_options = b'\352A\273\001\n\036logging.googleapis.com/LogSink\022\037projects/{project}/sinks/{sink}\022)organizations/{organization}/sinks/{sink}\022\035folders/{folder}/sinks/{sink}\022.billingAccounts/{billing_account}/sinks/{sink}'
  _BIGQUERYOPTIONS.fields_by_name['use_partitioned_tables']._options = None
  _BIGQUERYOPTIONS.fields_by_name['use_partitioned_tables']._serialized_options = b'\342A\001\001'
  _BIGQUERYOPTIONS.fields_by_name['uses_timestamp_column_partitioning']._options = None
  _BIGQUERYOPTIONS.fields_by_name['uses_timestamp_column_partitioning']._serialized_options = b'\342A\001\003'
  _LISTBUCKETSREQUEST.fields_by_name['parent']._options = None
  _LISTBUCKETSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 logging.googleapis.com/LogBucket'
  _LISTBUCKETSREQUEST.fields_by_name['page_token']._options = None
  _LISTBUCKETSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTBUCKETSREQUEST.fields_by_name['page_size']._options = None
  _LISTBUCKETSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _CREATEBUCKETREQUEST.fields_by_name['parent']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 logging.googleapis.com/LogBucket'
  _CREATEBUCKETREQUEST.fields_by_name['bucket_id']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['bucket_id']._serialized_options = b'\342A\001\002'
  _CREATEBUCKETREQUEST.fields_by_name['bucket']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['bucket']._serialized_options = b'\342A\001\002'
  _UPDATEBUCKETREQUEST.fields_by_name['name']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogBucket'
  _UPDATEBUCKETREQUEST.fields_by_name['bucket']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['bucket']._serialized_options = b'\342A\001\002'
  _UPDATEBUCKETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _GETBUCKETREQUEST.fields_by_name['name']._options = None
  _GETBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogBucket'
  _DELETEBUCKETREQUEST.fields_by_name['name']._options = None
  _DELETEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogBucket'
  _UNDELETEBUCKETREQUEST.fields_by_name['name']._options = None
  _UNDELETEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n logging.googleapis.com/LogBucket'
  _LISTVIEWSREQUEST.fields_by_name['parent']._options = None
  _LISTVIEWSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _LISTVIEWSREQUEST.fields_by_name['page_token']._options = None
  _LISTVIEWSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTVIEWSREQUEST.fields_by_name['page_size']._options = None
  _LISTVIEWSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _CREATEVIEWREQUEST.fields_by_name['parent']._options = None
  _CREATEVIEWREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _CREATEVIEWREQUEST.fields_by_name['view_id']._options = None
  _CREATEVIEWREQUEST.fields_by_name['view_id']._serialized_options = b'\342A\001\002'
  _CREATEVIEWREQUEST.fields_by_name['view']._options = None
  _CREATEVIEWREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\002'
  _UPDATEVIEWREQUEST.fields_by_name['name']._options = None
  _UPDATEVIEWREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _UPDATEVIEWREQUEST.fields_by_name['view']._options = None
  _UPDATEVIEWREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\002'
  _UPDATEVIEWREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEVIEWREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _GETVIEWREQUEST.fields_by_name['name']._options = None
  _GETVIEWREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036logging.googleapis.com/LogView'
  _DELETEVIEWREQUEST.fields_by_name['name']._options = None
  _DELETEVIEWREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036logging.googleapis.com/LogView'
  _LISTSINKSREQUEST.fields_by_name['parent']._options = None
  _LISTSINKSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \022\036logging.googleapis.com/LogSink'
  _LISTSINKSREQUEST.fields_by_name['page_token']._options = None
  _LISTSINKSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTSINKSREQUEST.fields_by_name['page_size']._options = None
  _LISTSINKSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _GETSINKREQUEST.fields_by_name['sink_name']._options = None
  _GETSINKREQUEST.fields_by_name['sink_name']._serialized_options = b'\342A\001\002\372A \n\036logging.googleapis.com/LogSink'
  _CREATESINKREQUEST.fields_by_name['parent']._options = None
  _CREATESINKREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \022\036logging.googleapis.com/LogSink'
  _CREATESINKREQUEST.fields_by_name['sink']._options = None
  _CREATESINKREQUEST.fields_by_name['sink']._serialized_options = b'\342A\001\002'
  _CREATESINKREQUEST.fields_by_name['unique_writer_identity']._options = None
  _CREATESINKREQUEST.fields_by_name['unique_writer_identity']._serialized_options = b'\342A\001\001'
  _UPDATESINKREQUEST.fields_by_name['sink_name']._options = None
  _UPDATESINKREQUEST.fields_by_name['sink_name']._serialized_options = b'\342A\001\002\372A \n\036logging.googleapis.com/LogSink'
  _UPDATESINKREQUEST.fields_by_name['sink']._options = None
  _UPDATESINKREQUEST.fields_by_name['sink']._serialized_options = b'\342A\001\002'
  _UPDATESINKREQUEST.fields_by_name['unique_writer_identity']._options = None
  _UPDATESINKREQUEST.fields_by_name['unique_writer_identity']._serialized_options = b'\342A\001\001'
  _UPDATESINKREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESINKREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _DELETESINKREQUEST.fields_by_name['sink_name']._options = None
  _DELETESINKREQUEST.fields_by_name['sink_name']._serialized_options = b'\342A\001\002\372A \n\036logging.googleapis.com/LogSink'
  _LOGEXCLUSION.fields_by_name['name']._options = None
  _LOGEXCLUSION.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _LOGEXCLUSION.fields_by_name['description']._options = None
  _LOGEXCLUSION.fields_by_name['description']._serialized_options = b'\342A\001\001'
  _LOGEXCLUSION.fields_by_name['filter']._options = None
  _LOGEXCLUSION.fields_by_name['filter']._serialized_options = b'\342A\001\002'
  _LOGEXCLUSION.fields_by_name['disabled']._options = None
  _LOGEXCLUSION.fields_by_name['disabled']._serialized_options = b'\342A\001\001'
  _LOGEXCLUSION.fields_by_name['create_time']._options = None
  _LOGEXCLUSION.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _LOGEXCLUSION.fields_by_name['update_time']._options = None
  _LOGEXCLUSION.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _LOGEXCLUSION._options = None
  _LOGEXCLUSION._serialized_options = b'\352A\350\001\n#logging.googleapis.com/LogExclusion\022)projects/{project}/exclusions/{exclusion}\0223organizations/{organization}/exclusions/{exclusion}\022\'folders/{folder}/exclusions/{exclusion}\0228billingAccounts/{billing_account}/exclusions/{exclusion}'
  _LISTEXCLUSIONSREQUEST.fields_by_name['parent']._options = None
  _LISTEXCLUSIONSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A%\022#logging.googleapis.com/LogExclusion'
  _LISTEXCLUSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTEXCLUSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTEXCLUSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTEXCLUSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _GETEXCLUSIONREQUEST.fields_by_name['name']._options = None
  _GETEXCLUSIONREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#logging.googleapis.com/LogExclusion'
  _CREATEEXCLUSIONREQUEST.fields_by_name['parent']._options = None
  _CREATEEXCLUSIONREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A%\022#logging.googleapis.com/LogExclusion'
  _CREATEEXCLUSIONREQUEST.fields_by_name['exclusion']._options = None
  _CREATEEXCLUSIONREQUEST.fields_by_name['exclusion']._serialized_options = b'\342A\001\002'
  _UPDATEEXCLUSIONREQUEST.fields_by_name['name']._options = None
  _UPDATEEXCLUSIONREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#logging.googleapis.com/LogExclusion'
  _UPDATEEXCLUSIONREQUEST.fields_by_name['exclusion']._options = None
  _UPDATEEXCLUSIONREQUEST.fields_by_name['exclusion']._serialized_options = b'\342A\001\002'
  _UPDATEEXCLUSIONREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEEXCLUSIONREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\002'
  _DELETEEXCLUSIONREQUEST.fields_by_name['name']._options = None
  _DELETEEXCLUSIONREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#logging.googleapis.com/LogExclusion'
  _GETCMEKSETTINGSREQUEST.fields_by_name['name']._options = None
  _GETCMEKSETTINGSREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#logging.googleapis.com/CmekSettings'
  _UPDATECMEKSETTINGSREQUEST.fields_by_name['name']._options = None
  _UPDATECMEKSETTINGSREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _UPDATECMEKSETTINGSREQUEST.fields_by_name['cmek_settings']._options = None
  _UPDATECMEKSETTINGSREQUEST.fields_by_name['cmek_settings']._serialized_options = b'\342A\001\002'
  _UPDATECMEKSETTINGSREQUEST.fields_by_name['update_mask']._options = None
  _UPDATECMEKSETTINGSREQUEST.fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _CMEKSETTINGS.fields_by_name['name']._options = None
  _CMEKSETTINGS.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _CMEKSETTINGS.fields_by_name['service_account_id']._options = None
  _CMEKSETTINGS.fields_by_name['service_account_id']._serialized_options = b'\342A\001\003'
  _CMEKSETTINGS._options = None
  _CMEKSETTINGS._serialized_options = b'\352A\300\001\n#logging.googleapis.com/CmekSettings\022\037projects/{project}/cmekSettings\022)organizations/{organization}/cmekSettings\022\035folders/{folder}/cmekSettings\022.billingAccounts/{billing_account}/cmekSettings'
  _CONFIGSERVICEV2._options = None
  _CONFIGSERVICEV2._serialized_options = b'\312A\026logging.googleapis.com\322A\302\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/logging.admin,https://www.googleapis.com/auth/logging.read'
  _CONFIGSERVICEV2.methods_by_name['ListBuckets']._options = None
  _CONFIGSERVICEV2.methods_by_name['ListBuckets']._serialized_options = b'\332A\006parent\202\323\344\223\002\355\001\022$/v2/{parent=*/*/locations/*}/bucketsZ-\022+/v2/{parent=projects/*/locations/*}/bucketsZ2\0220/v2/{parent=organizations/*/locations/*}/bucketsZ,\022*/v2/{parent=folders/*/locations/*}/bucketsZ4\0222/v2/{parent=billingAccounts/*/locations/*}/buckets'
  _CONFIGSERVICEV2.methods_by_name['GetBucket']._options = None
  _CONFIGSERVICEV2.methods_by_name['GetBucket']._serialized_options = b'\202\323\344\223\002\341\001\022$/v2/{name=*/*/locations/*/buckets/*}Z-\022+/v2/{name=projects/*/locations/*/buckets/*}Z2\0220/v2/{name=organizations/*/locations/*/buckets/*}Z,\022*/v2/{name=folders/*/locations/*/buckets/*}Z(\022&/v2/{name=billingAccounts/*/buckets/*}'
  _CONFIGSERVICEV2.methods_by_name['CreateBucket']._options = None
  _CONFIGSERVICEV2.methods_by_name['CreateBucket']._serialized_options = b'\202\323\344\223\002\225\002\"$/v2/{parent=*/*/locations/*}/buckets:\006bucketZ5\"+/v2/{parent=projects/*/locations/*}/buckets:\006bucketZ:\"0/v2/{parent=organizations/*/locations/*}/buckets:\006bucketZ4\"*/v2/{parent=folders/*/locations/*}/buckets:\006bucketZ<\"2/v2/{parent=billingAccounts/*/locations/*}/buckets:\006bucket'
  _CONFIGSERVICEV2.methods_by_name['UpdateBucket']._options = None
  _CONFIGSERVICEV2.methods_by_name['UpdateBucket']._serialized_options = b'\202\323\344\223\002\225\0022$/v2/{name=*/*/locations/*/buckets/*}:\006bucketZ52+/v2/{name=projects/*/locations/*/buckets/*}:\006bucketZ:20/v2/{name=organizations/*/locations/*/buckets/*}:\006bucketZ42*/v2/{name=folders/*/locations/*/buckets/*}:\006bucketZ<22/v2/{name=billingAccounts/*/locations/*/buckets/*}:\006bucket'
  _CONFIGSERVICEV2.methods_by_name['DeleteBucket']._options = None
  _CONFIGSERVICEV2.methods_by_name['DeleteBucket']._serialized_options = b'\202\323\344\223\002\355\001*$/v2/{name=*/*/locations/*/buckets/*}Z-*+/v2/{name=projects/*/locations/*/buckets/*}Z2*0/v2/{name=organizations/*/locations/*/buckets/*}Z,**/v2/{name=folders/*/locations/*/buckets/*}Z4*2/v2/{name=billingAccounts/*/locations/*/buckets/*}'
  _CONFIGSERVICEV2.methods_by_name['UndeleteBucket']._options = None
  _CONFIGSERVICEV2.methods_by_name['UndeleteBucket']._serialized_options = b'\202\323\344\223\002\251\002\"-/v2/{name=*/*/locations/*/buckets/*}:undelete:\001*Z9\"4/v2/{name=projects/*/locations/*/buckets/*}:undelete:\001*Z>\"9/v2/{name=organizations/*/locations/*/buckets/*}:undelete:\001*Z8\"3/v2/{name=folders/*/locations/*/buckets/*}:undelete:\001*Z@\";/v2/{name=billingAccounts/*/locations/*/buckets/*}:undelete:\001*'
  _CONFIGSERVICEV2.methods_by_name['ListViews']._options = None
  _CONFIGSERVICEV2.methods_by_name['ListViews']._serialized_options = b'\332A\006parent\202\323\344\223\002\225\002\022,/v2/{parent=*/*/locations/*/buckets/*}/viewsZ5\0223/v2/{parent=projects/*/locations/*/buckets/*}/viewsZ:\0228/v2/{parent=organizations/*/locations/*/buckets/*}/viewsZ4\0222/v2/{parent=folders/*/locations/*/buckets/*}/viewsZ<\022:/v2/{parent=billingAccounts/*/locations/*/buckets/*}/views'
  _CONFIGSERVICEV2.methods_by_name['GetView']._options = None
  _CONFIGSERVICEV2.methods_by_name['GetView']._serialized_options = b'\202\323\344\223\002\211\002\022,/v2/{name=*/*/locations/*/buckets/*/views/*}Z5\0223/v2/{name=projects/*/locations/*/buckets/*/views/*}Z:\0228/v2/{name=organizations/*/locations/*/buckets/*/views/*}Z4\0222/v2/{name=folders/*/locations/*/buckets/*/views/*}Z0\022./v2/{name=billingAccounts/*/buckets/*/views/*}'
  _CONFIGSERVICEV2.methods_by_name['CreateView']._options = None
  _CONFIGSERVICEV2.methods_by_name['CreateView']._serialized_options = b'\202\323\344\223\002\263\002\",/v2/{parent=*/*/locations/*/buckets/*}/views:\004viewZ;\"3/v2/{parent=projects/*/locations/*/buckets/*}/views:\004viewZ@\"8/v2/{parent=organizations/*/locations/*/buckets/*}/views:\004viewZ:\"2/v2/{parent=folders/*/locations/*/buckets/*}/views:\004viewZB\":/v2/{parent=billingAccounts/*/locations/*/buckets/*}/views:\004view'
  _CONFIGSERVICEV2.methods_by_name['UpdateView']._options = None
  _CONFIGSERVICEV2.methods_by_name['UpdateView']._serialized_options = b'\202\323\344\223\002\263\0022,/v2/{name=*/*/locations/*/buckets/*/views/*}:\004viewZ;23/v2/{name=projects/*/locations/*/buckets/*/views/*}:\004viewZ@28/v2/{name=organizations/*/locations/*/buckets/*/views/*}:\004viewZ:22/v2/{name=folders/*/locations/*/buckets/*/views/*}:\004viewZB2:/v2/{name=billingAccounts/*/locations/*/buckets/*/views/*}:\004view'
  _CONFIGSERVICEV2.methods_by_name['DeleteView']._options = None
  _CONFIGSERVICEV2.methods_by_name['DeleteView']._serialized_options = b'\202\323\344\223\002\225\002*,/v2/{name=*/*/locations/*/buckets/*/views/*}Z5*3/v2/{name=projects/*/locations/*/buckets/*/views/*}Z:*8/v2/{name=organizations/*/locations/*/buckets/*/views/*}Z4*2/v2/{name=folders/*/locations/*/buckets/*/views/*}Z<*:/v2/{name=billingAccounts/*/locations/*/buckets/*/views/*}'
  _CONFIGSERVICEV2.methods_by_name['ListSinks']._options = None
  _CONFIGSERVICEV2.methods_by_name['ListSinks']._serialized_options = b'\332A\006parent\202\323\344\223\002\247\001\022\026/v2/{parent=*/*}/sinksZ\037\022\035/v2/{parent=projects/*}/sinksZ$\022\"/v2/{parent=organizations/*}/sinksZ\036\022\034/v2/{parent=folders/*}/sinksZ&\022$/v2/{parent=billingAccounts/*}/sinks'
  _CONFIGSERVICEV2.methods_by_name['GetSink']._options = None
  _CONFIGSERVICEV2.methods_by_name['GetSink']._serialized_options = b'\332A\tsink_name\202\323\344\223\002\300\001\022\033/v2/{sink_name=*/*/sinks/*}Z$\022\"/v2/{sink_name=projects/*/sinks/*}Z)\022\'/v2/{sink_name=organizations/*/sinks/*}Z#\022!/v2/{sink_name=folders/*/sinks/*}Z+\022)/v2/{sink_name=billingAccounts/*/sinks/*}'
  _CONFIGSERVICEV2.methods_by_name['CreateSink']._options = None
  _CONFIGSERVICEV2.methods_by_name['CreateSink']._serialized_options = b'\332A\013parent,sink\202\323\344\223\002\305\001\"\026/v2/{parent=*/*}/sinks:\004sinkZ%\"\035/v2/{parent=projects/*}/sinks:\004sinkZ*\"\"/v2/{parent=organizations/*}/sinks:\004sinkZ$\"\034/v2/{parent=folders/*}/sinks:\004sinkZ,\"$/v2/{parent=billingAccounts/*}/sinks:\004sink'
  _CONFIGSERVICEV2.methods_by_name['UpdateSink']._options = None
  _CONFIGSERVICEV2.methods_by_name['UpdateSink']._serialized_options = b'\332A\032sink_name,sink,update_mask\332A\016sink_name,sink\202\323\344\223\002\231\003\032\033/v2/{sink_name=*/*/sinks/*}:\004sinkZ*\032\"/v2/{sink_name=projects/*/sinks/*}:\004sinkZ/\032\'/v2/{sink_name=organizations/*/sinks/*}:\004sinkZ)\032!/v2/{sink_name=folders/*/sinks/*}:\004sinkZ1\032)/v2/{sink_name=billingAccounts/*/sinks/*}:\004sinkZ*2\"/v2/{sink_name=projects/*/sinks/*}:\004sinkZ/2\'/v2/{sink_name=organizations/*/sinks/*}:\004sinkZ)2!/v2/{sink_name=folders/*/sinks/*}:\004sinkZ12)/v2/{sink_name=billingAccounts/*/sinks/*}:\004sink'
  _CONFIGSERVICEV2.methods_by_name['DeleteSink']._options = None
  _CONFIGSERVICEV2.methods_by_name['DeleteSink']._serialized_options = b'\332A\tsink_name\202\323\344\223\002\300\001*\033/v2/{sink_name=*/*/sinks/*}Z$*\"/v2/{sink_name=projects/*/sinks/*}Z)*\'/v2/{sink_name=organizations/*/sinks/*}Z#*!/v2/{sink_name=folders/*/sinks/*}Z+*)/v2/{sink_name=billingAccounts/*/sinks/*}'
  _CONFIGSERVICEV2.methods_by_name['ListExclusions']._options = None
  _CONFIGSERVICEV2.methods_by_name['ListExclusions']._serialized_options = b'\332A\006parent\202\323\344\223\002\300\001\022\033/v2/{parent=*/*}/exclusionsZ$\022\"/v2/{parent=projects/*}/exclusionsZ)\022\'/v2/{parent=organizations/*}/exclusionsZ#\022!/v2/{parent=folders/*}/exclusionsZ+\022)/v2/{parent=billingAccounts/*}/exclusions'
  _CONFIGSERVICEV2.methods_by_name['GetExclusion']._options = None
  _CONFIGSERVICEV2.methods_by_name['GetExclusion']._serialized_options = b'\332A\004name\202\323\344\223\002\300\001\022\033/v2/{name=*/*/exclusions/*}Z$\022\"/v2/{name=projects/*/exclusions/*}Z)\022\'/v2/{name=organizations/*/exclusions/*}Z#\022!/v2/{name=folders/*/exclusions/*}Z+\022)/v2/{name=billingAccounts/*/exclusions/*}'
  _CONFIGSERVICEV2.methods_by_name['CreateExclusion']._options = None
  _CONFIGSERVICEV2.methods_by_name['CreateExclusion']._serialized_options = b'\332A\020parent,exclusion\202\323\344\223\002\367\001\"\033/v2/{parent=*/*}/exclusions:\texclusionZ/\"\"/v2/{parent=projects/*}/exclusions:\texclusionZ4\"\'/v2/{parent=organizations/*}/exclusions:\texclusionZ.\"!/v2/{parent=folders/*}/exclusions:\texclusionZ6\")/v2/{parent=billingAccounts/*}/exclusions:\texclusion'
  _CONFIGSERVICEV2.methods_by_name['UpdateExclusion']._options = None
  _CONFIGSERVICEV2.methods_by_name['UpdateExclusion']._serialized_options = b'\332A\032name,exclusion,update_mask\202\323\344\223\002\367\0012\033/v2/{name=*/*/exclusions/*}:\texclusionZ/2\"/v2/{name=projects/*/exclusions/*}:\texclusionZ42\'/v2/{name=organizations/*/exclusions/*}:\texclusionZ.2!/v2/{name=folders/*/exclusions/*}:\texclusionZ62)/v2/{name=billingAccounts/*/exclusions/*}:\texclusion'
  _CONFIGSERVICEV2.methods_by_name['DeleteExclusion']._options = None
  _CONFIGSERVICEV2.methods_by_name['DeleteExclusion']._serialized_options = b'\332A\004name\202\323\344\223\002\300\001*\033/v2/{name=*/*/exclusions/*}Z$*\"/v2/{name=projects/*/exclusions/*}Z)*\'/v2/{name=organizations/*/exclusions/*}Z#*!/v2/{name=folders/*/exclusions/*}Z+*)/v2/{name=billingAccounts/*/exclusions/*}'
  _CONFIGSERVICEV2.methods_by_name['GetCmekSettings']._options = None
  _CONFIGSERVICEV2.methods_by_name['GetCmekSettings']._serialized_options = b'\202\323\344\223\002H\022\033/v2/{name=*/*}/cmekSettingsZ)\022\'/v2/{name=organizations/*}/cmekSettings'
  _CONFIGSERVICEV2.methods_by_name['UpdateCmekSettings']._options = None
  _CONFIGSERVICEV2.methods_by_name['UpdateCmekSettings']._serialized_options = b'\202\323\344\223\002f2\033/v2/{name=*/*}/cmekSettings:\rcmek_settingsZ82\'/v2/{name=organizations/*}/cmekSettings:\rcmek_settings'
  _globals['_LIFECYCLESTATE']._serialized_start=6210
  _globals['_LIFECYCLESTATE']._serialized_end=6293
  _globals['_LOGBUCKET']._serialized_start=305
  _globals['_LOGBUCKET']._serialized_end=863
  _globals['_LOGVIEW']._serialized_start=866
  _globals['_LOGVIEW']._serialized_end=1382
  _globals['_LOGSINK']._serialized_start=1385
  _globals['_LOGSINK']._serialized_end=2169
  _globals['_LOGSINK_VERSIONFORMAT']._serialized_start=1901
  _globals['_LOGSINK_VERSIONFORMAT']._serialized_end=1964
  _globals['_BIGQUERYOPTIONS']._serialized_start=2171
  _globals['_BIGQUERYOPTIONS']._serialized_end=2276
  _globals['_LISTBUCKETSREQUEST']._serialized_start=2279
  _globals['_LISTBUCKETSREQUEST']._serialized_end=2409
  _globals['_LISTBUCKETSRESPONSE']._serialized_start=2411
  _globals['_LISTBUCKETSRESPONSE']._serialized_end=2504
  _globals['_CREATEBUCKETREQUEST']._serialized_start=2507
  _globals['_CREATEBUCKETREQUEST']._serialized_end=2664
  _globals['_UPDATEBUCKETREQUEST']._serialized_start=2667
  _globals['_UPDATEBUCKETREQUEST']._serialized_end=2852
  _globals['_GETBUCKETREQUEST']._serialized_start=2854
  _globals['_GETBUCKETREQUEST']._serialized_end=2929
  _globals['_DELETEBUCKETREQUEST']._serialized_start=2931
  _globals['_DELETEBUCKETREQUEST']._serialized_end=3009
  _globals['_UNDELETEBUCKETREQUEST']._serialized_start=3011
  _globals['_UNDELETEBUCKETREQUEST']._serialized_end=3091
  _globals['_LISTVIEWSREQUEST']._serialized_start=3093
  _globals['_LISTVIEWSREQUEST']._serialized_end=3184
  _globals['_LISTVIEWSRESPONSE']._serialized_start=3186
  _globals['_LISTVIEWSRESPONSE']._serialized_end=3273
  _globals['_CREATEVIEWREQUEST']._serialized_start=3275
  _globals['_CREATEVIEWREQUEST']._serialized_end=3387
  _globals['_UPDATEVIEWREQUEST']._serialized_start=3390
  _globals['_UPDATEVIEWREQUEST']._serialized_end=3532
  _globals['_GETVIEWREQUEST']._serialized_start=3534
  _globals['_GETVIEWREQUEST']._serialized_end=3605
  _globals['_DELETEVIEWREQUEST']._serialized_start=3607
  _globals['_DELETEVIEWREQUEST']._serialized_end=3681
  _globals['_LISTSINKSREQUEST']._serialized_start=3683
  _globals['_LISTSINKSREQUEST']._serialized_end=3809
  _globals['_LISTSINKSRESPONSE']._serialized_start=3811
  _globals['_LISTSINKSRESPONSE']._serialized_end=3898
  _globals['_GETSINKREQUEST']._serialized_start=3900
  _globals['_GETSINKREQUEST']._serialized_end=3976
  _globals['_CREATESINKREQUEST']._serialized_start=3979
  _globals['_CREATESINKREQUEST']._serialized_end=4141
  _globals['_UPDATESINKREQUEST']._serialized_start=4144
  _globals['_UPDATESINKREQUEST']._serialized_end=4364
  _globals['_DELETESINKREQUEST']._serialized_start=4366
  _globals['_DELETESINKREQUEST']._serialized_end=4445
  _globals['_LOGEXCLUSION']._serialized_start=4448
  _globals['_LOGEXCLUSION']._serialized_end=4904
  _globals['_LISTEXCLUSIONSREQUEST']._serialized_start=4907
  _globals['_LISTEXCLUSIONSREQUEST']._serialized_end=5043
  _globals['_LISTEXCLUSIONSRESPONSE']._serialized_start=5045
  _globals['_LISTEXCLUSIONSRESPONSE']._serialized_end=5147
  _globals['_GETEXCLUSIONREQUEST']._serialized_start=5149
  _globals['_GETEXCLUSIONREQUEST']._serialized_end=5230
  _globals['_CREATEEXCLUSIONREQUEST']._serialized_start=5233
  _globals['_CREATEEXCLUSIONREQUEST']._serialized_end=5377
  _globals['_UPDATEEXCLUSIONREQUEST']._serialized_start=5380
  _globals['_UPDATEEXCLUSIONREQUEST']._serialized_end=5577
  _globals['_DELETEEXCLUSIONREQUEST']._serialized_start=5579
  _globals['_DELETEEXCLUSIONREQUEST']._serialized_end=5663
  _globals['_GETCMEKSETTINGSREQUEST']._serialized_start=5665
  _globals['_GETCMEKSETTINGSREQUEST']._serialized_end=5749
  _globals['_UPDATECMEKSETTINGSREQUEST']._serialized_start=5752
  _globals['_UPDATECMEKSETTINGSREQUEST']._serialized_end=5916
  _globals['_CMEKSETTINGS']._serialized_start=5919
  _globals['_CMEKSETTINGS']._serialized_end=6208
  _globals['_CONFIGSERVICEV2']._serialized_start=6296
  _globals['_CONFIGSERVICEV2']._serialized_end=14324
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/dynamic_ot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/config/trace/v2/dynamic_ot.proto\x12\x15\x65nvoy.config.trace.v2\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"T\n\x0f\x44ynamicOtConfig\x12\x18\n\x07library\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x85\x01\n#io.envoyproxy.envoy.config.trace.v2B\x0e\x44ynamicOtProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v2.dynamic_ot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v2B\016DynamicOtProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\272\200\310\321\006\002\020\001'
  _DYNAMICOTCONFIG.fields_by_name['library']._options = None
  _DYNAMICOTCONFIG.fields_by_name['library']._serialized_options = b'\372B\004r\002 \001'
  _globals['_DYNAMICOTCONFIG']._serialized_start=151
  _globals['_DYNAMICOTCONFIG']._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rbac/matchers/upstream_ip_port/v3/upstream_ip_port_matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQenvoy/extensions/rbac/matchers/upstream_ip_port/v3/upstream_ip_port_matcher.proto\x12\x32\x65nvoy.extensions.rbac.matchers.upstream_ip_port.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1dudpa/annotations/status.proto\"\x85\x01\n\x15UpstreamIpPortMatcher\x12\x34\n\x0bupstream_ip\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12\x36\n\x13upstream_port_range\x18\x02 \x01(\x0b\x32\x19.envoy.type.v3.Int64RangeB\xd6\x01\n@io.envoyproxy.envoy.extensions.rbac.matchers.upstream_ip_port.v3B\x1aUpstreamIpPortMatcherProtoP\x01Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/rbac/matchers/upstream_ip_port/v3;upstream_ip_portv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.rbac.matchers.upstream_ip_port.v3.upstream_ip_port_matcher_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.rbac.matchers.upstream_ip_port.v3B\032UpstreamIpPortMatcherProtoP\001Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/rbac/matchers/upstream_ip_port/v3;upstream_ip_portv3\272\200\310\321\006\002\020\002'
  _globals['_UPSTREAMIPPORTMATCHER']._serialized_start=232
  _globals['_UPSTREAMIPPORTMATCHER']._serialized_end=365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/transcoder/v2/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/config/filter/http/transcoder/v2/transcoder.proto\x12&envoy.config.filter.http.transcoder.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9f\x04\n\x12GrpcJsonTranscoder\x12\x1a\n\x10proto_descriptor\x18\x01 \x01(\tH\x00\x12\x1e\n\x14proto_descriptor_bin\x18\x04 \x01(\x0cH\x00\x12\x1a\n\x08services\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12^\n\rprint_options\x18\x03 \x01(\x0b\x32G.envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions\x12$\n\x1cmatch_incoming_request_route\x18\x05 \x01(\x08\x12 \n\x18ignored_query_parameters\x18\x06 \x03(\t\x12\x14\n\x0c\x61uto_mapping\x18\x07 \x01(\x08\x12\'\n\x1fignore_unknown_query_parameters\x18\x08 \x01(\x08\x12\x1b\n\x13\x63onvert_grpc_status\x18\t \x01(\x08\x1a\x95\x01\n\x0cPrintOptions\x12\x16\n\x0e\x61\x64\x64_whitespace\x18\x01 \x01(\x08\x12%\n\x1d\x61lways_print_primitive_fields\x18\x02 \x01(\x08\x12\"\n\x1a\x61lways_print_enums_as_ints\x18\x03 \x01(\x08\x12\"\n\x1apreserve_proto_field_names\x18\x04 \x01(\x08\x42\x15\n\x0e\x64\x65scriptor_set\x12\x03\xf8\x42\x01\x42\xea\x01\n4io.envoyproxy.envoy.config.filter.http.transcoder.v2B\x0fTranscoderProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/transcoder/v2;transcoderv2\xf2\x98\xfe\x8f\x05\x37\x12\x35\x65nvoy.extensions.filters.http.grpc_json_transcoder.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.transcoder.v2.transcoder_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.config.filter.http.transcoder.v2B\017TranscoderProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/transcoder/v2;transcoderv2\362\230\376\217\0057\0225envoy.extensions.filters.http.grpc_json_transcoder.v3\272\200\310\321\006\002\020\001'
  _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._options = None
  _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._serialized_options = b'\370B\001'
  _GRPCJSONTRANSCODER.fields_by_name['services']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['services']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_GRPCJSONTRANSCODER']._serialized_start=188
  _globals['_GRPCJSONTRANSCODER']._serialized_end=731
  _globals['_GRPCJSONTRANSCODER_PRINTOPTIONS']._serialized_start=559
  _globals['_GRPCJSONTRANSCODER_PRINTOPTIONS']._serialized_end=708
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/dynamic_forward_proxy/v2alpha/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.dynamic_forward_proxy.v2alpha import dns_cache_pb2 as envoy_dot_config_dot_common_dot_dynamic__forward__proxy_dot_v2alpha_dot_dns__cache__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/config/cluster/dynamic_forward_proxy/v2alpha/cluster.proto\x12\x32\x65nvoy.config.cluster.dynamic_forward_proxy.v2alpha\x1a\x41\x65nvoy/config/common/dynamic_forward_proxy/v2alpha/dns_cache.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"v\n\rClusterConfig\x12\x65\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32\x41.envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xef\x01\n@io.envoyproxy.envoy.config.cluster.dynamic_forward_proxy.v2alphaB\x0c\x43lusterProtoP\x01ZYgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/dynamic_forward_proxy/v2alpha\xf2\x98\xfe\x8f\x05\x34\x12\x32\x65nvoy.extensions.clusters.dynamic_forward_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.dynamic_forward_proxy.v2alpha.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.config.cluster.dynamic_forward_proxy.v2alphaB\014ClusterProtoP\001ZYgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/dynamic_forward_proxy/v2alpha\362\230\376\217\0054\0222envoy.extensions.clusters.dynamic_forward_proxy.v3\272\200\310\321\006\002\020\001'
  _CLUSTERCONFIG.fields_by_name['dns_cache_config']._options = None
  _CLUSTERCONFIG.fields_by_name['dns_cache_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CLUSTERCONFIG']._serialized_start=275
  _globals['_CLUSTERCONFIG']._serialized_end=393
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2


class ClusterDiscoveryServiceStub(object):
    """[#protodoc-title: CDS]

    Return list of all clusters this proxy will load balance to.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamClusters = channel.stream_stream(
                '/envoy.service.cluster.v3.ClusterDiscoveryService/StreamClusters',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )
        self.DeltaClusters = channel.stream_stream(
                '/envoy.service.cluster.v3.ClusterDiscoveryService/DeltaClusters',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
                )
        self.FetchClusters = channel.unary_unary(
                '/envoy.service.cluster.v3.ClusterDiscoveryService/FetchClusters',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )


class ClusterDiscoveryServiceServicer(object):
    """[#protodoc-title: CDS]

    Return list of all clusters this proxy will load balance to.
    """

    def StreamClusters(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeltaClusters(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchClusters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamClusters': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamClusters,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
            'DeltaClusters': grpc.stream_stream_rpc_method_handler(
                    servicer.DeltaClusters,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.SerializeToString,
            ),
            'FetchClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchClusters,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.cluster.v3.ClusterDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClusterDiscoveryService(object):
    """[#protodoc-title: CDS]

    Return list of all clusters this proxy will load balance to.
    """

    @staticmethod
    def StreamClusters(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.cluster.v3.ClusterDiscoveryService/StreamClusters',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeltaClusters(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.cluster.v3.ClusterDiscoveryService/DeltaClusters',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/envoy.service.cluster.v3.ClusterDiscoveryService/FetchClusters',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/tls.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3envoy/extensions/transport_sockets/tls/v3/tls.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\"envoy/config/core/v3/address.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc1\x02\n\x12UpstreamTlsContext\x12W\n\x12\x63ommon_tls_context\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext\x12\x15\n\x03sni\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03(\xff\x01\x12\x1b\n\x13\x61llow_renegotiation\x18\x03 \x01(\x08\x12\x36\n\x10max_session_keys\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x39\n\x15\x65nforce_rsa_key_usage\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.auth.UpstreamTlsContext\"\xa8\x07\n\x14\x44ownstreamTlsContext\x12W\n\x12\x63ommon_tls_context\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext\x12>\n\x1arequire_client_certificate\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0brequire_sni\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12^\n\x13session_ticket_keys\x18\x04 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.TlsSessionTicketKeysH\x00\x12k\n%session_ticket_keys_sds_secret_config\x18\x05 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigH\x00\x12.\n$disable_stateless_session_resumption\x18\x07 \x01(\x08H\x00\x12+\n#disable_stateful_session_resumption\x18\n \x01(\x08\x12\x44\n\x0fsession_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x10\xfa\x42\r\xaa\x01\n\x1a\x06\x08\x80\x80\x80\x80\x10\x32\x00\x12v\n\x12ocsp_staple_policy\x18\x08 \x01(\x0e\x32P.envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContext.OcspStaplePolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x43\n\x1f\x66ull_scan_certs_on_sni_mismatch\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"N\n\x10OcspStaplePolicy\x12\x14\n\x10LENIENT_STAPLING\x10\x00\x12\x13\n\x0fSTRICT_STAPLING\x10\x01\x12\x0f\n\x0bMUST_STAPLE\x10\x02:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.auth.DownstreamTlsContextB\x1a\n\x18session_ticket_keys_type\"\x9f\x01\n\tTlsKeyLog\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12<\n\x13local_address_range\x18\x02 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\x12=\n\x14remote_address_range\x18\x03 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRange\"\xab\x13\n\x10\x43ommonTlsContext\x12L\n\ntls_params\x18\x01 \x01(\x0b\x32\x38.envoy.extensions.transport_sockets.tls.v3.TlsParameters\x12S\n\x10tls_certificates\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.transport_sockets.tls.v3.TlsCertificate\x12\x66\n\"tls_certificate_sds_secret_configs\x18\x06 \x03(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfig\x12w\n!tls_certificate_provider_instance\x18\x0e \x01(\x0b\x32L.envoy.extensions.transport_sockets.tls.v3.CertificateProviderPluginInstance\x12\x8a\x01\n$tls_certificate_certificate_provider\x18\t \x01(\x0b\x32O.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x9b\x01\n-tls_certificate_certificate_provider_instance\x18\x0b \x01(\x0b\x32W.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstanceB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x65\n\x12validation_context\x18\x03 \x01(\x0b\x32G.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContextH\x00\x12j\n$validation_context_sds_secret_config\x18\x07 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigH\x00\x12\x87\x01\n\x1b\x63ombined_validation_context\x18\x08 \x01(\x0b\x32`.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CombinedCertificateValidationContextH\x00\x12\x8f\x01\n\'validation_context_certificate_provider\x18\n \x01(\x0b\x32O.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\xa0\x01\n0validation_context_certificate_provider_instance\x18\x0c \x01(\x0b\x32W.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstanceB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x16\n\x0e\x61lpn_protocols\x18\x04 \x03(\t\x12\x45\n\x11\x63ustom_handshaker\x18\r \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x45\n\x07key_log\x18\x0f \x01(\x0b\x32\x34.envoy.extensions.transport_sockets.tls.v3.TlsKeyLog\x1a\x7f\n\x13\x43\x65rtificateProvider\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x42\n\x0ctyped_config\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x42\r\n\x06\x63onfig\x12\x03\xf8\x42\x01\x1aN\n\x1b\x43\x65rtificateProviderInstance\x12\x15\n\rinstance_name\x18\x01 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x02 \x01(\t\x1a\x92\x05\n$CombinedCertificateValidationContext\x12u\n\x1a\x64\x65\x66\x61ult_validation_context\x18\x01 \x01(\x0b\x32G.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12r\n$validation_context_sds_secret_config\x18\x02 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x8d\x01\n\'validation_context_certificate_provider\x18\x03 \x01(\x0b\x32O.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x9e\x01\n0validation_context_certificate_provider_instance\x18\x04 \x01(\x0b\x32W.envoy.extensions.transport_sockets.tls.v3.CommonTlsContext.CertificateProviderInstanceB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0:N\x9a\xc5\x88\x1eI\nGenvoy.api.v2.auth.CommonTlsContext.CombinedCertificateValidationContext:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.auth.CommonTlsContextB\x19\n\x17validation_context_typeJ\x04\x08\x05\x10\x06\x42\xa5\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x08TlsProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tls.v3.tls_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\010TlsProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\272\200\310\321\006\002\020\002'
  _UPSTREAMTLSCONTEXT.fields_by_name['sni']._options = None
  _UPSTREAMTLSCONTEXT.fields_by_name['sni']._serialized_options = b'\372B\005r\003(\377\001'
  _UPSTREAMTLSCONTEXT._options = None
  _UPSTREAMTLSCONTEXT._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.auth.UpstreamTlsContext'
  _DOWNSTREAMTLSCONTEXT.fields_by_name['session_timeout']._options = None
  _DOWNSTREAMTLSCONTEXT.fields_by_name['session_timeout']._serialized_options = b'\372B\r\252\001\n\032\006\010\200\200\200\200\0202\000'
  _DOWNSTREAMTLSCONTEXT.fields_by_name['ocsp_staple_policy']._options = None
  _DOWNSTREAMTLSCONTEXT.fields_by_name['ocsp_staple_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _DOWNSTREAMTLSCONTEXT._options = None
  _DOWNSTREAMTLSCONTEXT._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.auth.DownstreamTlsContext'
  _TLSKEYLOG.fields_by_name['path']._options = None
  _TLSKEYLOG.fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _COMMONTLSCONTEXT_CERTIFICATEPROVIDER.oneofs_by_name['config']._options = None
  _COMMONTLSCONTEXT_CERTIFICATEPROVIDER.oneofs_by_name['config']._serialized_options = b'\370B\001'
  _COMMONTLSCONTEXT_CERTIFICATEPROVIDER.fields_by_name['name']._options = None
  _COMMONTLSCONTEXT_CERTIFICATEPROVIDER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['default_validation_context']._options = None
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['default_validation_context']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_sds_secret_config']._options = None
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_sds_secret_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider']._options = None
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider_instance']._options = None
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT.fields_by_name['validation_context_certificate_provider_instance']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT._options = None
  _COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT._serialized_options = b'\232\305\210\036I\nGenvoy.api.v2.auth.CommonTlsContext.CombinedCertificateValidationContext'
  _COMMONTLSCONTEXT.fields_by_name['tls_certificate_certificate_provider']._options = None
  _COMMONTLSCONTEXT.fields_by_name['tls_certificate_certificate_provider']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONTLSCONTEXT.fields_by_name['tls_certificate_certificate_provider_instance']._options = None
  _COMMONTLSCONTEXT.fields_by_name['tls_certificate_certificate_provider_instance']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider']._options = None
  _COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider_instance']._options = None
  _COMMONTLSCONTEXT.fields_by_name['validation_context_certificate_provider_instance']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _COMMONTLSCONTEXT._options = None
  _COMMONTLSCONTEXT._serialized_options = b'\232\305\210\036$\n\"envoy.api.v2.auth.CommonTlsContext'
  _globals['_UPSTREAMTLSCONTEXT']._serialized_start=477
  _globals['_UPSTREAMTLSCONTEXT']._serialized_end=798
  _globals['_DOWNSTREAMTLSCONTEXT']._serialized_start=801
  _globals['_DOWNSTREAMTLSCONTEXT']._serialized_end=1737
  _globals['_DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY']._serialized_start=1584
  _globals['_DOWNSTREAMTLSCONTEXT_OCSPSTAPLEPOLICY']._serialized_end=1662
  _globals['_TLSKEYLOG']._serialized_start=1740
  _globals['_TLSKEYLOG']._serialized_end=1899
  _globals['_COMMONTLSCONTEXT']._serialized_start=1902
  _globals['_COMMONTLSCONTEXT']._serialized_end=4377
  _globals['_COMMONTLSCONTEXT_CERTIFICATEPROVIDER']._serialized_start=3433
  _globals['_COMMONTLSCONTEXT_CERTIFICATEPROVIDER']._serialized_end=3560
  _globals['_COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE']._serialized_start=3562
  _globals['_COMMONTLSCONTEXT_CERTIFICATEPROVIDERINSTANCE']._serialized_end=3640
  _globals['_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT']._serialized_start=3643
  _globals['_COMMONTLSCONTEXT_COMBINEDCERTIFICATEVALIDATIONCONTEXT']._serialized_end=4301
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/v3/percent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65nvoy/type/v3/percent.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"L\n\x07Percent\x12&\n\x05value\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00Y@)\x00\x00\x00\x00\x00\x00\x00\x00:\x19\x9a\xc5\x88\x1e\x14\n\x12\x65nvoy.type.Percent\"\xdb\x01\n\x11\x46ractionalPercent\x12\x11\n\tnumerator\x18\x01 \x01(\r\x12O\n\x0b\x64\x65nominator\x18\x02 \x01(\x0e\x32\x30.envoy.type.v3.FractionalPercent.DenominatorTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"=\n\x0f\x44\x65nominatorType\x12\x0b\n\x07HUNDRED\x10\x00\x12\x10\n\x0cTEN_THOUSAND\x10\x01\x12\x0b\n\x07MILLION\x10\x02:#\x9a\xc5\x88\x1e\x1e\n\x1c\x65nvoy.type.FractionalPercentBr\n\x1bio.envoyproxy.envoy.type.v3B\x0cPercentProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.v3.percent_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.envoyproxy.envoy.type.v3B\014PercentProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\272\200\310\321\006\002\020\002'
  _PERCENT.fields_by_name['value']._options = None
  _PERCENT.fields_by_name['value']._serialized_options = b'\372B\024\022\022\031\000\000\000\000\000\000Y@)\000\000\000\000\000\000\000\000'
  _PERCENT._options = None
  _PERCENT._serialized_options = b'\232\305\210\036\024\n\022envoy.type.Percent'
  _FRACTIONALPERCENT.fields_by_name['denominator']._options = None
  _FRACTIONALPERCENT.fields_by_name['denominator']._serialized_options = b'\372B\005\202\001\002\020\001'
  _FRACTIONALPERCENT._options = None
  _FRACTIONALPERCENT._serialized_options = b'\232\305\210\036\036\n\034envoy.type.FractionalPercent'
  _globals['_PERCENT']._serialized_start=137
  _globals['_PERCENT']._serialized_end=213
  _globals['_FRACTIONALPERCENT']._serialized_start=216
  _globals['_FRACTIONALPERCENT']._serialized_end=435
  _globals['_FRACTIONALPERCENT_DENOMINATORTYPE']._serialized_start=337
  _globals['_FRACTIONALPERCENT_DENOMINATORTYPE']._serialized_end=398
# @@protoc_insertion_point(module_scope)
